"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const graphql_1 = require("graphql");
const graphql_query_complexity_1 = require("graphql-query-complexity");
function plugin(options) {
    return {
        requestDidStart({ schema }) {
            return {
                didResolveOperation({ request, document }) {
                    const complexity = graphql_query_complexity_1.getComplexity({
                        schema,
                        query: request.operationName
                            ? graphql_1.separateOperations(document)[request.operationName]
                            : document,
                        estimators: options.estimators,
                        variables: request.variables,
                    });
                    if (complexity > options.maximumComplexity) {
                        throw new Error(`Query is too complex. Requested complexity ${complexity} is greater than ${options.maximumComplexity}.`);
                    }
                },
            };
        },
    };
}
exports.default = plugin;
//# sourceMappingURL=ApolloServerPluginQueryComplexity.js.map